@@ -1,16 +1,21 @@
 from django.db import models
 from ckeditor.fields import RichTextField
 
-from django.contrib.sites.models import Site
-from django.contrib.sites.managers import CurrentSiteManager
+try:
+    from django.contrib.sites.models import Site
+    from django.contrib.sites.managers import CurrentSiteManager
+    site = True
+except ImportError:
+    site = None
 
 class CmsContent(models.Model):
     """ CMS like Content area """
     name = models.CharField(max_length=255, unique=True)
     content = RichTextField(blank=True)
-    site = models.ForeignKey(Site)
     objects = models.Manager()
-    on_site = CurrentSiteManager()
+    if site:
+        on_site = CurrentSiteManager()
+        site = models.ForeignKey(Site)
 
     def __unicode__(self):
         return self.name
